summaryrefslogtreecommitdiff
path: root/src/Models/EventConfig.php
diff options
context:
space:
mode:
authorIgor Scheller <igor.scheller@igorshp.de>2019-07-28 19:13:05 +0200
committerIgor Scheller <igor.scheller@igorshp.de>2019-07-29 00:58:06 +0200
commit5d3efb625477f4412d0360244737a7524e7f5149 (patch)
tree56045c046587806ac9b9a7a8707a4597463746d4 /src/Models/EventConfig.php
parent219c54411bb765bebd7813ad3e49ab05acf0b150 (diff)
Models: Updated method and property hints
Diffstat (limited to 'src/Models/EventConfig.php')
-rw-r--r--src/Models/EventConfig.php18
1 files changed, 10 insertions, 8 deletions
diff --git a/src/Models/EventConfig.php b/src/Models/EventConfig.php
index 576a8f0e..5e32d6ee 100644
--- a/src/Models/EventConfig.php
+++ b/src/Models/EventConfig.php
@@ -3,17 +3,19 @@
namespace Engelsystem\Models;
use Carbon\Carbon;
+use Illuminate\Database\Eloquent\Collection;
+use Illuminate\Database\Query\Builder as QueryBuilder;
/**
- * @property string $name
- * @property string $value
- * @property \Carbon\Carbon $created_at
- * @property \Carbon\Carbon $updated_at
+ * @property string $name
+ * @property string $value
+ * @property Carbon $created_at
+ * @property Carbon $updated_at
*
* @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\EventConfig[] whereName($value)
* @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\EventConfig[] whereValue($value)
* @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\EventConfig[] whereCreatedAt($value)
* @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\EventConfig[] whereUpdatedAt($value)
*/
class EventConfig extends BaseModel
{
@@ -3,17 +3,19 @@
*
- * @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\EventConfig[] whereName($value)
- * @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\EventConfig[] whereValue($value)
- * @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\EventConfig[] whereCreatedAt($value)
- * @method static \Illuminate\Database\Query\Builder|\Engelsystem\Models\EventConfig[] whereUpdatedAt($value)
+ * @method static QueryBuilder|Collection|EventConfig[] whereName($value)
+ * @method static QueryBuilder|Collection|EventConfig[] whereValue($value)
+ * @method static QueryBuilder|Collection|EventConfig[] whereCreatedAt($value)
+ * @method static QueryBuilder|Collection|EventConfig[] whereUpdatedAt($value)
*/
class EventConfig extends BaseModel